Change Log
~~~~~~~~~~
All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog <http://keepachangelog.com/>`_.

====================
 5.0.0 - 2019-03-31
====================


Added
-------

* Initial Release
* Support for Oracle NoSQL Database Cloud Service
